### 第1講 サンプルコード
#' 
#' このファイルには資料の中の例題や演習問題の解答例があります
#' コメント行は "#'" で開始され，RStudio では緑(既定値)で表示されます
#' コメント内の "@..." は
#'   @exercise 例題 (スライドの説明と並行して実習)
#'   @practice 演習 (時間を取って各自で実習)
#'   @notes 注意 (講義の補足説明)
#'   @appendix 補遺 (講義では扱い切れなかった付加的な事柄)
#' のタグで，RStudio では青(既定値)でハイライトされます
#'

#' @exercise コンソール上での計算

#' 与えられた式の計算をコンソール上で実行してみよう
#' 1 x 2 + 3^2 の計算
1 * 2 + 3^2
#' sin(2π) の計算
sin(2*pi)
#' √2 + |-0.6| の計算
sqrt(2) + abs(-0.6)

#' @notes
#' 演算子の前後に空白があっても良い(空白は可読性のために適宜利用する)
#' 2文字以上の演算子の途中には空白は入れられない(例: 羃乗の別記法の"**")
#' πは "pi" として定義されている
#' "e-16" は10の-16乗の意味
#' 計算結果は数値誤差のため厳密に0にならないことがある
#' 利用環境下で扱うことのできる数値については ".Machine" に保存されている
#' 特に上記の丸め誤差については ".Machine$double.eps" を参照

#' @exercise 関数の実行

#' 正弦関数(引数が1つ)の計算例
sin(x = pi/2) 
sin(pi/2) # 引数名は省略でき，前の行とこの行は同じ結果になる

#' 対数関数(引数が2つ)の計算例
#' 以下は擬似コード．a, b を適当な数値に置き換えて実行しなさい
log(a, b) # 底を b とする a の対数 
log(x = a, base = b) #上と同値
log(base = b, x = a) #上と同値(引数名があれば順序は自由に変えられる)
log(b, a) # = log(x=b,base=a) (引数名がなければ規定の順序で解釈される)
log(a) # 自然対数 =log(a,base=exp(1))

#' @exercise ヘルプの使い方

#' 関数 log() に関するヘルプの例
help(log) # Helpタブに結果は表示される
?log # 上と同値
example(log) # ヘルプ内の例を実行
help.search("log") # "log"に関連する項目は？
??"log" # 上と同値

#' 数値を変数 foo に代入する
(foo <- 3) # foo <- 3; print(foo) と等価
#' 変数 foo を用いて計算し，結果を bar に代入する
bar <- sin(2/3*pi) + cos(foo * pi/4) # 計算結果は表示されない
#' 変数 bar の内容を表示する
print(bar)

#' @exercise 自作関数の定義

#' 縦の長さ a, 横の長さ b (既定値は1) の長方形の面積
foo <- function(a, b = 1){ 
  out <- a * b 
  return(out) # 計算結果を外に返却
}
#' 実行例
foo(2, 3) # foo(a = 2, b = 3) と同義
foo(2) # foo(a = 2, b = 1) と同義

#' 変数や関数を定義して計算する方法
(x <- 1:10/10)
foo <- function(x) sin(x)/x # 式の計算結果を返却(returnを省略可)
foo(x)
#' 変数や関数を定義せずに計算する方法
(function(x) sin(x)/x)(1:10/10)
(\(x) sin(x)/x)(1:10/10) # R 4.1 以降の短縮表現

#' 関数 1/(1+x^2) を区間 [0,1] で積分 (関数オブジェクトを渡す書き方)
f <- function(x) 1/(1+x^2) # 関数を定義
integrate(f, 0, 1) # pi/4 
#' 関数 e^(-x^2/2) を実軸全体で積分(Gauss積分) (関数を定義しない書き方)
integrate(\(x)exp(-x^2/2), -Inf, Inf) # sqrt(2*pi)
